OC.L10N.register(
    "photos",
    {
    "Photos" : "Photos",
    "Videos" : "Videos",
    "People" : "Shaxs",
    "Favorites" : "Favorites",
    "Shared with you" : "Shared with you",
    "Tags" : "Tags",
    "Places" : "Joylar",
    "Back" : "Orqaga",
    "Save" : "Saqlash",
    "Copy public link" : "Umumiy havoladan nusxa oling",
    "Favorite" : "Favorite",
    "Add to {destination}" : " {destination}ni qo`shish",
    "Home" : "Home",
    "View" : "Ko'rish",
    "Remove from favorites" : "Sevimlilardan olib tashlang",
    "Last week" : "O`tgan yil",
    "Details" : "Details",
    "Back to {folder}" : "{folder}ga qaytish",
    "Add" : "Add"
},
"nplurals=1; plural=0;");
